diff --git a/main.c b/main.c
index 1deb208..d693f4e 100644
--- a/main.c
+++ b/main.c
@@ -51,7 +51,10 @@ static void scan_filter_match(struct bt_scan_device_info *device_info,
 			      struct bt_scan_filter_match *filter_match,
 			      bool connectable)
 {
+	int err; 
 	char addr[BT_ADDR_LE_STR_LEN];
+	struct bt_conn_le_create_param *conn_params;
+	static uint32_t matched_filters;
 
 	bt_addr_le_to_str(device_info->recv_info->addr, addr, sizeof(addr));
 
@@ -59,6 +62,43 @@ static void scan_filter_match(struct bt_scan_device_info *device_info,
 
 	printk("Filters matched. Address: %s connectable: %s\n",
 		addr, connectable ? "yes" : "no");
+
+	if (filter_match->name.match) {
+		matched_filters |= BT_SCAN_NAME_FILTER;
+	} else if (filter_match->uuid.match) {
+		matched_filters |= BT_SCAN_UUID_FILTER;
+	}
+
+	/* Initiate connection if we have had a match on both filters */
+	//TODO: check if address filters where matched for the same device? 
+	if ((matched_filters & BT_SCAN_NAME_FILTER) &&
+	    (matched_filters & BT_SCAN_UUID_FILTER)) {
+		
+		matched_filters = 0;
+
+		err = bt_scan_stop();
+		if (err) {
+			LOG_INF("Stop LE scan failed (err %d)", err);
+		}
+
+		conn_params = BT_CONN_LE_CREATE_PARAM(BT_CONN_LE_OPT_NO_1M,
+						      BT_GAP_SCAN_FAST_INTERVAL,
+						      BT_GAP_SCAN_FAST_INTERVAL);
+
+		err = bt_conn_le_create(device_info->recv_info->addr, conn_params,
+					BT_LE_CONN_PARAM_DEFAULT, &default_conn);
+		if (err) {
+			LOG_INF("Create conn failed (err %d)", err);
+
+			err = bt_scan_start(BT_SCAN_TYPE_SCAN_ACTIVE);
+			if (err) {
+				LOG_INF("Scanning failed to start (err %d)", err);
+				return;
+			}
+		}
+
+		LOG_INF("Connection pending");
+	}
 }
 
 static void scan_connecting_error(struct bt_scan_device_info *device_info)
@@ -131,7 +171,7 @@ static void scan_init(void)
 	int err;
 
 	struct bt_scan_init_param scan_init = {
-		.connect_if_match = 1,
+		.connect_if_match = 0,
 		//.scan_param = BT_LE_SCAN_PASSIVE,
         .scan_param = BT_LE_SCAN_ACTIVE,
 		.conn_param = BT_LE_CONN_PARAM_DEFAULT
@@ -147,7 +187,20 @@ static void scan_init(void)
 		return;
 	}
 
-	err = bt_scan_filter_enable(BT_SCAN_UUID_FILTER, false);
+	err = bt_scan_filter_add(BT_SCAN_FILTER_TYPE_UUID, BT_UUID_DECLARE_128(K_BLE_UUID_WPC_VAL));
+	if (err) {
+		printk("Scanning filters cannot be set (err %d)\n", err);
+
+		return;
+	}
+
+	err = bt_scan_filter_add(BT_SCAN_FILTER_TYPE_NAME, <insert name of target device here>);
+	if (err) {
+		LOG_ERR("Scanning filters cannot be set (err %d)", err);
+		return err;
+	}
+
+	err = bt_scan_filter_enable(BT_SCAN_UUID_FILTER | BT_SCAN_NAME_FILTER, false);
 	if (err) {
 		printk("Filters cannot be turned on (err %d)\n", err);
 	}
